BundleUiWriteAdapter class
Write adapter that implements UiPort from mcp_bundle.
Converts programmatically generated UI definition JSON into
bundle-compatible sections. Returns UiWriteOutput containing
UiSection and manifestMetadata map.
Single-direction adapter: toDefinition and toAppInfo throw UnsupportedError.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
fromDefinition(
Map< String, dynamic> definitionJson) → Future<UiResult< UiWriteOutput> > - Write: Convert UI definition JSON into bundle-compatible sections.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toAppInfo(
McpBundle bundle) → Future< UiResult< Map< >String, dynamic> > - Read: Extract lightweight app info for discovery/listing.
-
toDefinition(
McpBundle bundle) → Future< UiResult< Map< >String, dynamic> > -
Read: Convert
McpBundleinto runtime-consumable UI definition JSON. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited