GridViewBuilder class

Constructors

GridViewBuilder({required String items, required Map<String, dynamic> itemTemplate})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build() Map<String, dynamic>
childAspectRatio(double ratio) GridViewBuilder
crossAxisCount(int count) GridViewBuilder
crossAxisSpacing(double spacing) GridViewBuilder
mainAxisSpacing(double spacing) GridViewBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited