LinearBuilder class

Builder for linear layout (MCP UI DSL v1.0)

Constructors

LinearBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(Map<String, dynamic> child) LinearBuilder
addAll(List<Map<String, dynamic>> children) LinearBuilder
alignment(String alignment) LinearBuilder
build() Map<String, dynamic>
direction(String direction) LinearBuilder
distribution(String distribution) LinearBuilder
gap(double gap) LinearBuilder
Sets the spacing between children. The gap parameter maps to the spacing property in the generated JSON output.
horizontal() LinearBuilder
Set direction to horizontal
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
vertical() LinearBuilder
Set direction to vertical
wrap(bool wrap) LinearBuilder

Operators

operator ==(Object other) bool
The equality operator.
inherited